/**
 * @file PropertyFieldDropDownTreeViewHost.tsx
 * Renders the controls for PropertyFieldDropDownTreeView component
 *
 * @copyright 2016 Olivier Carpentier
 * Released under MIT licence
 */
import * as React from 'react';
import { IPropertyFieldDropDownTreeViewPropsInternal, IDropDownTreeViewNode } from './PropertyFieldDropDownTreeView';
/**
 * @interface
 * PropertyFieldDropDownTreeViewHost properties interface
 *
 */
export interface IPropertyFieldDropDownTreeViewHostProps extends IPropertyFieldDropDownTreeViewPropsInternal {
}
/**
 * @interface
 * PropertyFieldDropDownTreeViewHost state interface
 *
 */
export interface IPropertyFieldDropDownTreeViewHostState {
    isOpen: boolean;
    isHoverDropdown?: boolean;
    errorMessage?: string;
    tree: IDropDownTreeViewNode[];
    activeNodes: IDropDownTreeViewNode[];
}
/**
 * @class
 * Renders the controls for PropertyFieldDropDownTreeView component
 */
export default class PropertyFieldDropDownTreeViewHost extends React.Component<IPropertyFieldDropDownTreeViewHostProps, IPropertyFieldDropDownTreeViewHostState> {
    private async;
    private delayedValidate;
    private _key;
    /**
     * @function
     * Constructor
     */
    constructor(props: IPropertyFieldDropDownTreeViewHostProps);
    private getDefaultActiveNodesFromTree();
    /**
     * @function
     * Gets the list of activated nodes from the  selectedNodesIDs property
     * @param node
     */
    private getDefaultActiveNodes(node);
    /**
     * @function
     * Gets the given node position in the active nodes collection
     * @param node
     */
    private getSelectedNodePosition(node);
    /**
     * @function
     * Validates the new custom field value
     */
    private validate(value);
    /**
     * @function
     * Notifies the parent Web Part of a property value change
     */
    private notifyAfterValidate(oldValue, newValue);
    /**
     * @function
     * Called when the component will unmount
     */
    componentWillUnmount(): void;
    /**
     * @function
     * Function to open the dialog
     */
    private onOpenDialog();
    /**
     * @function
     * Mouse is hover the fontpicker
     */
    private mouseEnterDropDown(element?);
    /**
     * @function
     * Mouse is leaving the fontpicker
     */
    private mouseLeaveDropDown(element?);
    /**
     * clicks on a node
     * @param node
     */
    private onClickNode(node);
    /**
     * Saves the selected nodes
     */
    private saveSelectedNodes();
    /**
     * @function
     * Renders the given node
     * @param node
     */
    private renderNode(node);
    /**
     * Handles tree changes
     * @param rootNode
     * @param index
     */
    private handleTreeChange(rootNode, index);
    /**
     * @function
     * Renders the control
     */
    render(): JSX.Element;
}
