"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @file PropertyFieldSearchPropertiesPicker.ts
 * Define a custom field of type PropertyFieldSearchPropertiesPicker for
 * the SharePoint Framework (SPfx)
 *
 * @copyright 2017 Olivier Carpentier
 * Released under MIT licence
 */
var React = require("react");
var ReactDom = require("react-dom");
var sp_webpart_base_1 = require("@microsoft/sp-webpart-base");
var PropertyFieldSearchPropertiesPickerHost_1 = require("./PropertyFieldSearchPropertiesPickerHost");
/**
 * @interface
 * Represents a PropertyFieldSearchPropertiesPicker object
 *
 */
var PropertyFieldSearchPropertiesPickerBuilder = (function () {
    /**
     * @function
     * Ctor
     */
    function PropertyFieldSearchPropertiesPickerBuilder(_targetProperty, _properties) {
        //Properties defined by IPropertyPaneField
        this.type = sp_webpart_base_1.PropertyPaneFieldType.Custom;
        this.disabled = false;
        this.deferredValidationTime = 200;
        this.disableReactivePropertyChanges = false;
        this.render = this.render.bind(this);
        this.targetProperty = _properties.targetProperty;
        this.properties = _properties;
        this.label = _properties.label;
        this.selectedProperties = _properties.selectedProperties;
        this.suggestionsHeaderText = _properties.suggestionsHeaderText;
        this.noResultsFoundText = _properties.noResultsFoundText;
        this.loadingText = _properties.loadingText;
        this.properties.onDispose = this.dispose;
        this.properties.onRender = this.render;
        this.onPropertyChange = _properties.onPropertyChange;
        this.customProperties = _properties.properties;
        this.key = _properties.key;
        if (_properties.disabled === true)
            this.disabled = _properties.disabled;
        this.onGetErrorMessage = _properties.onGetErrorMessage;
        if (_properties.deferredValidationTime !== undefined)
            this.deferredValidationTime = _properties.deferredValidationTime;
        this.renderWebPart = _properties.render;
        if (_properties.disableReactivePropertyChanges !== undefined && _properties.disableReactivePropertyChanges != null)
            this.disableReactivePropertyChanges = _properties.disableReactivePropertyChanges;
    }
    /**
     * @function
     * Renders the picker field content
     */
    PropertyFieldSearchPropertiesPickerBuilder.prototype.render = function (elem) {
        //Construct the JSX properties
        var element = React.createElement(PropertyFieldSearchPropertiesPickerHost_1.default, {
            label: this.label,
            selectedProperties: this.selectedProperties,
            suggestionsHeaderText: this.suggestionsHeaderText,
            noResultsFoundText: this.noResultsFoundText,
            loadingText: this.loadingText,
            targetProperty: this.targetProperty,
            onDispose: this.dispose,
            onRender: this.render,
            onPropertyChange: this.onPropertyChange,
            properties: this.customProperties,
            key: this.key,
            disabled: this.disabled,
            onGetErrorMessage: this.onGetErrorMessage,
            deferredValidationTime: this.deferredValidationTime,
            render: this.renderWebPart,
            disableReactivePropertyChanges: this.disableReactivePropertyChanges
        });
        //Calls the REACT content generator
        ReactDom.render(element, elem);
    };
    /**
     * @function
     * Disposes the current object
     */
    PropertyFieldSearchPropertiesPickerBuilder.prototype.dispose = function (elem) {
    };
    return PropertyFieldSearchPropertiesPickerBuilder;
}());
/**
 * @function
 * Helper method to create the customer field on the PropertyPane.
 * @param targetProperty - Target property the custom field is associated to.
 * @param properties - Strongly typed custom field properties.
 */
function PropertyFieldSearchPropertiesPicker(targetProperty, properties) {
    //Create an internal properties object from the given properties
    var newProperties = {
        label: properties.label,
        targetProperty: targetProperty,
        selectedProperties: properties.selectedProperties,
        suggestionsHeaderText: properties.suggestionsHeaderText,
        noResultsFoundText: properties.noResultsFoundText,
        loadingText: properties.loadingText,
        onPropertyChange: properties.onPropertyChange,
        properties: properties.properties,
        onDispose: null,
        onRender: null,
        key: properties.key,
        disabled: properties.disabled,
        onGetErrorMessage: properties.onGetErrorMessage,
        deferredValidationTime: properties.deferredValidationTime,
        render: properties.render,
        disableReactivePropertyChanges: properties.disableReactivePropertyChanges
    };
    //Calls the PropertyFieldSearchPropertiesPicker builder object
    //This object will simulate a PropertyFieldCustom to manage his rendering process
    return new PropertyFieldSearchPropertiesPickerBuilder(targetProperty, newProperties);
}
exports.PropertyFieldSearchPropertiesPicker = PropertyFieldSearchPropertiesPicker;

//# sourceMappingURL=PropertyFieldSearchPropertiesPicker.js.map
