/**
 * @file PropertyFieldSortableListHost.tsx
 * Renders the controls for PropertyFieldSortableList component
 *
 * @copyright 2016 Olivier Carpentier
 * Released under MIT licence
 *
 */
import * as React from 'react';
import { IChoiceGroupOption } from 'office-ui-fabric-react/lib/ChoiceGroup';
import { IPropertyFieldSortableListPropsInternal } from './PropertyFieldSortableList';
/**
 * @interface
 * PropertyFieldSortableListHost properties interface
 *
 */
export interface IPropertyFieldSortableListHostProps extends IPropertyFieldSortableListPropsInternal {
}
/**
 * @interface
 * PropertyFieldSortableListHost state interface
 *
 */
export interface IPropertyFieldSortableListHostState {
    results: IChoiceGroupOption[];
    selectedKeys: string[];
    errorMessage?: string;
}
/**
 * @class
 * Renders the controls for PropertyFieldSortableList component
 */
export default class PropertyFieldSortableListHost extends React.Component<IPropertyFieldSortableListHostProps, IPropertyFieldSortableListHostState> {
    private async;
    private delayedValidate;
    private _key;
    /**
     * @function
     * Constructor
     */
    constructor(props: IPropertyFieldSortableListHostProps);
    /**
     * Inits the default items checked values
     */
    private initDefaultValue();
    /**
     * Gets the item from key
     * @param key
     */
    private getStateItemFromKey(key);
    /**
     * @function
     * Remove a string from the selected keys
     */
    private removeSelected(element);
    /**
     * @function
     * Raises when a list has been selected
     */
    private onChanged(element, isChecked);
    /**
     * @function
     * Validates the new custom field value
     */
    private validate(value);
    /**
     * @function
     * Notifies the parent Web Part of a property value change
     */
    private notifyAfterValidate(oldValue, newValue);
    /**
     * @function
     * Called when the component will unmount
     */
    componentWillUnmount(): void;
    private sortDescending(elm?);
    private sortAscending(elm?);
    /**
     * @function
     * Renders the SPListMultiplePicker controls with Office UI  Fabric
     */
    render(): JSX.Element;
}
