/**
 * @file PropertyFieldTreeViewHost.tsx
 * Renders the controls for PropertyFieldTreeView component
 *
 * @copyright 2017 Olivier Carpentier
 * Released under MIT licence
 */
import * as React from 'react';
import { IPropertyFieldTreeViewPropsInternal, ITreeViewNode } from './PropertyFieldTreeView';
/**
 * @interface
 * PropertyFieldTreeViewHost properties interface
 *
 */
export interface IPropertyFieldTreeViewHostProps extends IPropertyFieldTreeViewPropsInternal {
}
export interface IPropertyFieldTreeViewState {
    errorMessage: string;
    tree: ITreeViewNode[];
    activeNodes: ITreeViewNode[];
}
/**
 * @class
 * Renders the controls for PropertyFieldTreeView component
 */
export default class PropertyFieldTreeViewHost extends React.Component<IPropertyFieldTreeViewHostProps, IPropertyFieldTreeViewState> {
    private async;
    private delayedValidate;
    /**
     * @function
     * Constructor
     */
    constructor(props: IPropertyFieldTreeViewHostProps);
    private getDefaultActiveNodesFromTree();
    /**
     * @function
     * Gets the list of activated nodes from the  selectedNodesIDs property
     * @param node
     */
    private getDefaultActiveNodes(node);
    /**
     * @function
     * Validates the new custom field value
     */
    private validate(value);
    /**
     * @function
     * Notifies the parent Web Part of a property value change
     */
    private notifyAfterValidate(oldValue, newValue);
    /**
     * @function
     * Called when the component will unmount
     */
    componentWillUnmount(): void;
    /**
     * @function
     * Gets the given node position in the active nodes collection
     * @param node
     */
    private getSelectedNodePosition(node);
    /**
     * @function
     * Renders the given node
     * @param node
     */
    private renderNode(node);
    /**
     * clicks on a node
     * @param node
     */
    private onClickNode(node);
    /**
     * Saves the selected nodes
     */
    private saveSelectedNodes();
    /**
     * Handles tree changes
     * @param rootNode
     * @param index
     */
    private handleTreeChange(rootNode, index);
    /**
     * @function
     * Renders the controls
     */
    render(): JSX.Element;
}
